pub enum CommandArgument {
String(String),
Commands(ParsedCommands),
}Expand description
A parsed command argument.
Variants
String(String)
A scalar string argument after tmux quote and expansion handling.
Commands(ParsedCommands)
A brace-delimited nested command list.
Implementations
Sourceimpl CommandArgument
impl CommandArgument
Sourcepub fn as_string(&self) -> Option<&str>
pub fn as_string(&self) -> Option<&str>
Returns the string value when this is a scalar argument.
Sourcepub fn to_tmux_string(&self) -> String
pub fn to_tmux_string(&self) -> String
Converts the argument to a string suitable for the legacy CLI bridge.
Sourcepub fn to_tmux_reparse_string(&self) -> String
pub fn to_tmux_reparse_string(&self) -> String
Converts this argument to a lossless representation for an internal parse-execute bridge.