pub fn lookup_command(
name: &str,
) -> Result<&'static CommandEntry, CommandParseError>Expand description
Looks up a frozen tmux command using exact alias then unique name prefix.
pub fn lookup_command(
name: &str,
) -> Result<&'static CommandEntry, CommandParseError>Looks up a frozen tmux command using exact alias then unique name prefix.