pub struct ParsedCommand { /* private fields */ }Expand description
One parsed tmux command with a canonical command name.
Implementations
Sourceimpl ParsedCommand
impl ParsedCommand
Sourcepub fn arguments(&self) -> &[CommandArgument]
pub fn arguments(&self) -> &[CommandArgument]
Returns the parsed command arguments.
Sourcepub fn with_arguments(self, arguments: Vec<CommandArgument>) -> Self
pub fn with_arguments(self, arguments: Vec<CommandArgument>) -> Self
Returns this command with replacement arguments while preserving its source location.
Sourcepub fn start_line(&self) -> usize
pub fn start_line(&self) -> usize
Returns the first one-based input line occupied by this command.
Sourcepub fn to_tmux_string(&self) -> String
pub fn to_tmux_string(&self) -> String
Converts this command back to a tmux-style command string.
Sourcepub fn to_tmux_reparse_string(&self) -> String
pub fn to_tmux_reparse_string(&self) -> String
Converts this command to a lossless string for an internal parse-execute bridge.