pub enum CommandQueueResult {
Normal,
Error,
Wait,
}Expand description
Result status for a fired queue command.
Variants
Normal
The command completed and the queue may advance.
Error
The command failed; remaining items in the same group must be removed.
Wait
The command is waiting for an asynchronous continuation before the queue may advance.