CommandGroup

Struct CommandGroup 

pub struct CommandGroup(/* private fields */);
A tmux command queue group ID.

Commands in the same group are adjacent commands from one parsed command list that must be skipped together after the first execution error.

Implementations

Source

impl CommandGroup

pub const fn get(self) -> u64

Returns the numeric group ID.