pub struct QueuedCommand { /* private fields */ }Expand description
One parsed command plus the queue group assigned to it.
Implementations
Sourceimpl QueuedCommand
impl QueuedCommand
Sourcepub const fn command(&self) -> &ParsedCommand
pub const fn command(&self) -> &ParsedCommand
Returns the parsed command payload.
Sourcepub fn into_command(self) -> ParsedCommand
pub fn into_command(self) -> ParsedCommand
Consumes this item and returns the parsed command payload.
Sourcepub const fn group(&self) -> CommandGroup
pub const fn group(&self) -> CommandGroup
Returns this item’s queue group.