pub struct OutputCursor { /* private fields */ }Expand description
Independent read position for one pane-output subscriber.
Implementations
Sourceimpl OutputCursor
impl OutputCursor
Sourcepub const fn new(next_sequence: u64) -> Self
pub const fn new(next_sequence: u64) -> Self
Creates a cursor that will next read next_sequence.
Sourcepub const fn next_sequence(&self) -> u64
pub const fn next_sequence(&self) -> u64
Returns the next sequence this cursor expects to read.
Sourcepub const fn missed_events(&self) -> u64
pub const fn missed_events(&self) -> u64
Returns the total number of events this cursor has explicitly missed.