pub struct PaneOutputSubscriptionKey { /* private fields */ }Expand description
Runtime identity of a pane-output stream used for subscription accounting.
Implementations
Sourceimpl PaneOutputSubscriptionKey
impl PaneOutputSubscriptionKey
Sourcepub fn new(runtime_session_name: SessionName, pane_id: PaneId) -> Self
pub fn new(runtime_session_name: SessionName, pane_id: PaneId) -> Self
Builds a subscription key from the runtime session owner and pane id.
Sourcepub fn runtime_session_name(&self) -> &SessionName
pub fn runtime_session_name(&self) -> &SessionName
Returns the runtime session name that owns the pane output stream.