pub const fn hook_global_root(hook: HookName) -> HookGlobalRootExpand description
Returns the global hook root where tmux stores a hook.
pub const fn hook_global_root(hook: HookName) -> HookGlobalRootReturns the global hook root where tmux stores a hook.