validate_hook_registration

Function validate_hook_registration 

pub fn validate_hook_registration(
    hook: HookName,
    scope: &ScopeSelector,
) -> Result<(), RmuxError>
Validates that rmux ships the requested hook and that it may be stored at the requested scope.