CsiCommand

Enum CsiCommand 

pub enum CsiCommand {
Show 40 variants Ich, Cuu, Cud, Cuf, Cub, Cnl, Cpl, Hpa, Cup, Ed, El, Il, Dl, Dch, Su, SmGraphics, Sd, Ech, Cbt, Rep, Da, DaTwo, Vpa, Tbc, Sm, SmPrivate, Rm, RmPrivate, Sgr, Modset, Dsr, Modoff, DsrPrivate, QueryPrivate, Decscusr, Xda, Decstbm, Scp, Winops, Rcp,
}
CSI command types (40 entries).

Variants



Ich

ICH — Insert Character (@).



Cuu

CUU — Cursor Up (A).



Cud

CUD — Cursor Down (B).



Cuf

CUF — Cursor Forward (C).



Cub

CUB — Cursor Back (D).



Cnl

CNL — Cursor Next Line (E).



Cpl

CPL — Cursor Previous Line (F).



Hpa

HPA — Horizontal Position Absolute (G or `).



Cup

CUP — Cursor Position (H or f).



Ed

ED — Erase in Display (J).



El

EL — Erase in Line (K).



Il

IL — Insert Line (L).



Dl

DL — Delete Line (M).



Dch

DCH — Delete Character (P).



Su

SU — Scroll Up (S).



SmGraphics

SM_GRAPHICS — Set/query graphics mode (?S).



Sd

SD — Scroll Down (T).



Ech

ECH — Erase Character (X).



Cbt

CBT — Cursor Backward Tabulation (Z).



Rep

REP — Repeat preceding character (b).



Da

DA — Device Attributes primary (c).



DaTwo

DA_TWO — Device Attributes secondary (>c).



Vpa

VPA — Vertical Position Absolute (d).



Tbc

TBC — Tab Clear (g).



Sm

SM — Set Mode (h).



SmPrivate

SM_PRIVATE — Set Private Mode (?h).



Rm

RM — Reset Mode (l).



RmPrivate

RM_PRIVATE — Reset Private Mode (?l).



Sgr

SGR — Select Graphic Rendition (m).



Modset

MODSET — Set modifier key mode (>m).



Dsr

DSR — Device Status Report (n).



Modoff

MODOFF — Reset modifier key mode (>n).



DsrPrivate

DSR_PRIVATE — Private Device Status Report (?n).



QueryPrivate

QUERY_PRIVATE — DECRPM Query (?$p).



Decscusr

DECSCUSR — Set Cursor Style ( q).



Xda

XDA — Extended Device Attributes (>q).



Decstbm

DECSTBM — Set Top and Bottom Margins (r).



Scp

SCP — Save Cursor Position (s).



Winops

WINOPS — Window Operations (t).



Rcp

RCP — Restore Cursor Position (u).