pub struct KillPaneOutcome { /* private fields */ }Expand description
The result of removing one pane from a session window.
Implementations
Sourceimpl KillPaneOutcome
impl KillPaneOutcome
Sourcepub fn removed_pane_ids(&self) -> &[PaneId]
pub fn removed_pane_ids(&self) -> &[PaneId]
Returns the stable pane identities removed by the operation.
Sourcepub const fn window_destroyed(&self) -> bool
pub const fn window_destroyed(&self) -> bool
Returns whether removing the pane also destroyed its window.