pub struct ScreenCellView { /* private fields */ }Expand description
Read-only copy of one rendered screen cell for copy-mode consumers.
Implementations
Sourceimpl ScreenCellView
impl ScreenCellView
Sourcepub const fn is_padding(&self) -> bool
pub const fn is_padding(&self) -> bool
Returns whether the cell is padding for a wide glyph.