SetBufferOutcome

Struct SetBufferOutcome 

pub struct SetBufferOutcome { /* private fields */ }
The outcome of a set operation on the buffer store.

Implementations

Source

impl SetBufferOutcome

pub fn buffer_name(&self) -> Option<&str>

Returns the name of the created or replaced buffer.

pub fn evicted(&self) -> &[String]

Returns the names of evicted unnamed buffers.