TargetFindFlags

Struct TargetFindFlags 

pub struct TargetFindFlags(/* private fields */);
Flag bitset matching tmux CMD_FIND_* resolution controls.

Implementations

Source

impl TargetFindFlags

pub const NONE: Self

No find flags.

pub const PREFER_UNATTACHED: Self

Prefer unattached sessions when selecting a best session.

pub const QUIET: Self

Suppress emitted target lookup diagnostics.

pub const WINDOW_INDEX: Self

Allow a window target to resolve to a nonexistent index.

pub const DEFAULT_MARKED: Self

Use the marked pane as the default current target.

pub const EXACT_SESSION: Self

Suppress session prefix and fnmatch fallback.

pub const EXACT_WINDOW: Self

Suppress window prefix and fnmatch fallback.

pub const CANFAIL: Self

Allow target lookup failure to be represented by the caller.

pub const fn union(self, other: Self) -> Self

Returns a bitset containing both flag sets.

pub const fn contains(self, other: Self) -> bool

Returns whether every bit in other is present.