CommandArgument

Enum CommandArgument 

pub enum CommandArgument {
    String(String),
    Commands(ParsedCommands),
}
A parsed command argument.

Variants



String(String)

A scalar string argument after tmux quote and expansion handling.



Commands(ParsedCommands)

A brace-delimited nested command list.

Implementations

Source

impl CommandArgument

pub fn as_string(&self) -> Option<&str>

Returns the string value when this is a scalar argument.

pub fn to_tmux_string(&self) -> String

Converts the argument to a string suitable for the legacy CLI bridge.