CommandGrouping

Enum CommandGrouping 

pub enum CommandGrouping {
    ByLine,
    OneGroup,
}
Queue grouping mode captured while parsing a tmux command list.

Variants



ByLine

Commands that start on the same source line share one queue group.



OneGroup

All commands in the parsed list share one queue group.