CommandEntry

Struct CommandEntry 

pub struct CommandEntry {
    pub name: &'static str,
    pub alias: Option<&'static str>,
}
Frozen tmux command table entry used for command lookup.

Fields

name: &'static str

The canonical tmux command name.

alias: Option<&'static str>

The exact tmux alias, when the frozen entry declares one.