pub struct CommandGroup(/* private fields */);Expand description
A tmux command queue group ID.
Commands in the same group are adjacent commands from one parsed command list that must be skipped together after the first execution error.
Implementations