ShowOptionsMode

Enum ShowOptionsMode 

pub enum ShowOptionsMode {
    Resolved,
    Explicit,
}
Option rendering mode for show-options.

Variants



Resolved

Render the fully resolved view for each known option.



Explicit

Render only entries explicitly present in the selected tree.