pub struct RecentOutputSnapshot { /* private fields */ }Expand description
Bounded recent live bytes retained alongside an output ring.
Implementations
Sourceimpl RecentOutputSnapshot
impl RecentOutputSnapshot
Sourcepub fn bytes_from_sequence(&self, min_sequence: u64) -> &[u8] ⓘ
pub fn bytes_from_sequence(&self, min_sequence: u64) -> &[u8] ⓘ
Returns retained bytes whose contributing output event sequence is at
least min_sequence.
Sourcepub const fn oldest_sequence(&self) -> Option<u64>
pub const fn oldest_sequence(&self) -> Option<u64>
Returns the oldest output sequence contributing retained bytes.
Sourcepub const fn newest_sequence(&self) -> Option<u64>
pub const fn newest_sequence(&self) -> Option<u64>
Returns the newest output sequence contributing retained bytes.
Sourcepub fn oldest_sequence_at_or_after(&self, min_sequence: u64) -> Option<u64>
pub fn oldest_sequence_at_or_after(&self, min_sequence: u64) -> Option<u64>
Returns the oldest retained contributing sequence at or after
min_sequence.
Sourcepub fn starts_at_event_start(&self, sequence: u64) -> bool
pub fn starts_at_event_start(&self, sequence: u64) -> bool
Returns whether the retained bytes for sequence begin at that output
event’s first byte.