pub struct CommandTargetMetadata {
pub source: Option<CommandTargetSpec>,
pub target: Option<CommandTargetSpec>,
}Expand description
Per-command source and target lookup metadata.
Fields
source: Option<CommandTargetSpec>Metadata for the source target flag, when the command has one.
target: Option<CommandTargetSpec>Metadata for the target flag, when the command has one.