ScreenCellView

Struct ScreenCellView 

pub struct ScreenCellView { /* private fields */ }
Read-only copy of one rendered screen cell for copy-mode consumers.

Implementations

Source

impl ScreenCellView

pub fn text(&self) -> &str

Returns the stored cell text.

pub const fn width(&self) -> u8

Returns the display width of the cell.

pub const fn is_padding(&self) -> bool

Returns whether the cell is padding for a wide glyph.

pub const fn attr(&self) -> u16

Returns the cell attributes.

pub const fn fg(&self) -> Colour

Returns the cell foreground colour.

pub const fn bg(&self) -> Colour

Returns the cell background colour.

pub const fn us(&self) -> Colour

Returns the cell underline colour.

Returns the hyperlink inner ID for the cell.