TargetFindContext

Struct TargetFindContext 

pub struct TargetFindContext { /* private fields */ }
Current target context used for omitted targets and relative lookup.

Implementations

Source

impl TargetFindContext

pub const fn new(current: Option<Target>) -> Self

Creates a context with an optional current target.

pub fn from_target(target: Target) -> Self

Creates a context anchored to a concrete current target.

pub const fn current(&self) -> Option<&Target>

Returns the current target when one is available.

pub fn with_mouse_target(self, mouse_target: Option<Target>) -> Self

Returns a context extended with an active mouse target.

pub const fn mouse_target(&self) -> Option<&Target>

Returns the active mouse target when one is available.