pub struct TargetFindContext { /* private fields */ }Expand description
Current target context used for omitted targets and relative lookup.
Implementations
Sourceimpl TargetFindContext
impl TargetFindContext
Sourcepub const fn new(current: Option<Target>) -> Self
pub const fn new(current: Option<Target>) -> Self
Creates a context with an optional current target.
Sourcepub fn from_target(target: Target) -> Self
pub fn from_target(target: Target) -> Self
Creates a context anchored to a concrete current target.
Sourcepub const fn current(&self) -> Option<&Target>
pub const fn current(&self) -> Option<&Target>
Returns the current target when one is available.
Sourcepub fn with_mouse_target(self, mouse_target: Option<Target>) -> Self
pub fn with_mouse_target(self, mouse_target: Option<Target>) -> Self
Returns a context extended with an active mouse target.
Sourcepub const fn mouse_target(&self) -> Option<&Target>
pub const fn mouse_target(&self) -> Option<&Target>
Returns the active mouse target when one is available.