pub struct TargetFindFlags(/* private fields */);Expand description
Flag bitset matching tmux CMD_FIND_* resolution controls.
Implementations
Sourceimpl TargetFindFlags
impl TargetFindFlags
Sourcepub const PREFER_UNATTACHED: Self
pub const PREFER_UNATTACHED: Self
Prefer unattached sessions when selecting a best session.
Sourcepub const WINDOW_INDEX: Self
pub const WINDOW_INDEX: Self
Allow a window target to resolve to a nonexistent index.
Sourcepub const DEFAULT_MARKED: Self
pub const DEFAULT_MARKED: Self
Use the marked pane as the default current target.
Sourcepub const EXACT_SESSION: Self
pub const EXACT_SESSION: Self
Suppress session prefix and fnmatch fallback.
Sourcepub const EXACT_WINDOW: Self
pub const EXACT_WINDOW: Self
Suppress window prefix and fnmatch fallback.