pub struct TerminalPassthrough { /* private fields */ }Expand description
Opaque terminal command that must be forwarded to a capable outer terminal.
Implementations
Sourceimpl TerminalPassthrough
impl TerminalPassthrough
Sourcepub fn kitty_graphics(
cursor_x: u32,
cursor_y: u32,
payload: impl Into<Vec<u8>>,
) -> Self
pub fn kitty_graphics( cursor_x: u32, cursor_y: u32, payload: impl Into<Vec<u8>>, ) -> Self
Creates a Kitty graphics passthrough event at a pane-local cursor position.
Sourcepub const fn kind(&self) -> TerminalPassthroughKind
pub const fn kind(&self) -> TerminalPassthroughKind
Returns the passthrough protocol family.
Sourcepub const fn cursor_x(&self) -> u32
pub const fn cursor_x(&self) -> u32
Returns the pane-local cursor column captured when the sequence arrived.
Sourcepub const fn cursor_y(&self) -> u32
pub const fn cursor_y(&self) -> u32
Returns the pane-local cursor row captured when the sequence arrived.
Sourcepub fn render_sequence(&self) -> Vec<u8> ⓘ
pub fn render_sequence(&self) -> Vec<u8> ⓘ
Renders the passthrough as an outer-terminal escape sequence.